from django.http.response import JsonResponse

def login_valid():  
    return JsonResponse("Valid User",safe=False)

def loginApi_invalid():
    return "INVALID USER"

def postApi_valid():
    return "Added Successfully"

def postApi_invalid():
    return "Failed to Add"

def putApi_valid():
    return "Updated Successfully"

def putApi_invalid():
    return "Failed to Update"

def deleteApi_valid():
    return "Deleted Successfully"

def deleteApi_invalid():
    return "Failed to Delete"